==> openshift-client-5.5.0-sources.jar: io/fabric8/openshift/client/handlers/core/OverlappingRangeIPReservationHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.core;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.core.OverlappingRangeIPReservationOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservation;
import io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class OverlappingRangeIPReservationHandler implements ResourceHandler<OverlappingRangeIPReservation, OverlappingRangeIPReservationBuilder> {

  @Override
  public String getKind() {
    return OverlappingRangeIPReservation.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "whereabouts.cni.cncf.io/v1alpha1";
    }

  @Override
  public OverlappingRangeIPReservation create(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, boolean dryRun) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public OverlappingRangeIPReservation replace(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, boolean dryRun) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public OverlappingRangeIPReservation reload(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public OverlappingRangeIPReservationBuilder edit(OverlappingRangeIPReservation item) {
    return new OverlappingRangeIPReservationBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, OverlappingRangeIPReservation item, boolean dryRun) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, Watcher<OverlappingRangeIPReservation> watcher) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, String resourceVersion, Watcher<OverlappingRangeIPReservation> watcher) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, ListOptions options, Watcher<OverlappingRangeIPReservation> watcher) {
  return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public OverlappingRangeIPReservation waitUntilReady(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public OverlappingRangeIPReservation waitUntilCondition(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item, Predicate<OverlappingRangeIPReservation> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.6.0-sources.jar: io/fabric8/openshift/client/handlers/core/OverlappingRangeIPReservationHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.core;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.openshift.client.dsl.internal.core.OverlappingRangeIPReservationOperationsImpl;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservation;
import io.fabric8.openshift.api.model.whereabouts.v1alpha1.OverlappingRangeIPReservationBuilder;

public class OverlappingRangeIPReservationHandler implements ResourceHandler<OverlappingRangeIPReservation, OverlappingRangeIPReservationBuilder> {

  @Override
  public String getKind() {
    return OverlappingRangeIPReservation.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "whereabouts.cni.cncf.io/v1alpha1";
    }

  @Override
  public OverlappingRangeIPReservationBuilder edit(OverlappingRangeIPReservation item) {
    return new OverlappingRangeIPReservationBuilder(item);
  }

  @Override
  public Resource<OverlappingRangeIPReservation> resource(OkHttpClient client, Config config, String namespace, OverlappingRangeIPReservation item) {
    return new OverlappingRangeIPReservationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName());
  }

}
